/*
 * Copyright (C) 2013 Byron 3D Games Studio (www.b3dgs.com) Pierre-Alexandre (contact@b3dgs.com)
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
package com.b3dgs.lionengine.swing;

import javax.swing.JOptionPane;

/**
 * Static functions displaying message on screen.
 * 
 * @author Pierre-Alexandre (contact@b3dgs.com)
 */
public final class UtilityMessageBox
{
    /**
     * Displays an information message.
     * 
     * @param title The information title.
     * @param message The information message.
     */
    public static void information(String title, String message)
    {
        JOptionPane.showMessageDialog(null, message, title, JOptionPane.INFORMATION_MESSAGE);
    }

    /**
     * Displays a warning message.
     * 
     * @param title The warning title.
     * @param message The warning message.
     */
    public static void warning(String title, String message)
    {
        JOptionPane.showMessageDialog(null, message, title, JOptionPane.WARNING_MESSAGE);
    }

    /**
     * Displays an error message.
     * 
     * @param title The error title.
     * @param message The error message.
     */
    public static void error(String title, String message)
    {
        JOptionPane.showMessageDialog(null, message, title, JOptionPane.ERROR_MESSAGE);
    }

    /**
     * Private constructor.
     */
    private UtilityMessageBox()
    {
        throw new RuntimeException();
    }
}
